@@ -33,35 +33,27 @@
 /* FIXME bugzilla.eazel.com 1465: FtpUri / FtpConnectionUri refcounting or something. */
 /* FIXME bugzilla.eazel.com 1466: do_get_file_info_from_handle */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
-
-#include <ctype.h> /* for isspace */
-#include <stdlib.h> /* for atoi */
-#include <stdio.h> /* for sscanf */
-#include <string.h>
 
+/* Keep <sys/types.h> above any network includes for FreeBSD. */
 #include <sys/types.h>
+
+/* Keep <netinet/in.h> above <arpa/inet.h> for FreeBSD. */
 #include <netinet/in.h>
+
 #include <arpa/inet.h>
-
-#include <gtk/gtk.h>
-#ifdef HAVE_GCONF
-#include <gconf/gconf-client.h>
-#endif
-
-#include "gnome-vfs-context.h"
-#include "gnome-vfs-iobuf.h"
-#include "gnome-vfs-inet-connection.h"
-#include "gnome-vfs-method.h"
-#include "gnome-vfs-module.h"
-#include "gnome-vfs-module-shared.h"
-#include "gnome-vfs-mime.h"
-#include "gnome-vfs-parse-ls.h"
-#include "gnome-vfs-utils.h"
-
-#include "ftp-method.h"
+#include <libgnomevfs/gnome-vfs-context.h>
+#include <libgnomevfs/gnome-vfs-inet-connection.h>
+#include <libgnomevfs/gnome-vfs-iobuf.h>
+#include <libgnomevfs/gnome-vfs-method.h>
+#include <libgnomevfs/gnome-vfs-mime.h>
+#include <libgnomevfs/gnome-vfs-module-shared.h>
+#include <libgnomevfs/gnome-vfs-module.h>
+#include <libgnomevfs/gnome-vfs-parse-ls.h>
+#include <libgnomevfs/gnome-vfs-utils.h>
+#include <stdio.h> /* for sscanf */
+#include <stdlib.h> /* for atoi */
+#include <string.h>
 
 /* Standard FTP proxy port */
 #define DEFAULT_FTP_PROXY_PORT 8080
@@ -76,6 +68,31 @@
 #define IS_400(X) ((X) >= 400 && (X) < 500)
 #define IS_500(X) ((X) >= 500 && (X) < 600)
 
+typedef struct {
+	GnomeVFSMethodHandle method_handle;
+	GnomeVFSInetConnection *inet_connection;
+	GnomeVFSIOBuf *iobuf;
+	GnomeVFSURI *uri;
+	gchar *cwd;
+	GString *response_buffer;
+	gchar *response_message;
+	gint response_code;
+	GnomeVFSInetConnection *data_connection;
+	GnomeVFSIOBuf *data_iobuf;
+	enum {
+		FTP_NOTHING,
+		FTP_READ,
+		FTP_WRITE,
+		FTP_READDIR
+	} operation;
+	gchar *dirlist;
+	gchar *dirlistptr;
+	gchar *server_type; /* the response from TYPE */
+	gboolean anonymous;
+	GnomeVFSResult fivefifty; /* the result to return for an FTP 550 */
+	GnomeVFSFileInfoOptions file_info_options;
+} FtpConnection;
+
 static const char PROXY_KEY[] = "/system/gnome-vfs/http-proxy";
 static const char USE_PROXY_KEY[] = "/system/gnome-vfs/use-http-proxy";
 
@@ -91,7 +108,6 @@ static GnomeVFSResult do_open_directory  (GnomeVFSMethod                *method,
 					  GnomeVFSMethodHandle         **method_handle,
 					  GnomeVFSURI                   *uri,
 					  GnomeVFSFileInfoOptions        options,
-					  const GnomeVFSDirectoryFilter *filter,
 					  GnomeVFSContext               *context);
 static GnomeVFSResult do_close_directory (GnomeVFSMethod               *method,
 					  GnomeVFSMethodHandle          *method_handle,
@@ -101,8 +117,6 @@ static GnomeVFSResult do_read_directory  (GnomeVFSMethod               *method,
 		                          GnomeVFSFileInfo              *file_info,
 		                          GnomeVFSContext               *context);
 
-	/* FIXME bugzilla.eazel.com 1137: implement filters */
-
 guint                 ftp_connection_uri_hash  (gconstpointer c);
 gint                  ftp_connection_uri_equal (gconstpointer c, gconstpointer d);
 static GnomeVFSResult ftp_connection_acquire   (GnomeVFSURI *uri, 
@@ -122,33 +136,6 @@ G_LOCK_DEFINE_STATIC (spare_connections);
 static gint total_connections = 0;
 static gint allocated_connections = 0;
 
-#if 0
-struct CachedDirectoryListing {
-	GList *file_info_list;
-	time_t expires;
-};
-
-/* A GHashTable of directory listings */
-static GHashTable *cached_directory_listings = NULL;
-G_LOCK_DEFINE_STATIC (cached_directory_listings);
-
-static void dircache_setup() {
-	/* NOTE: only call this when you have the lock */
-	if (cached_directory_listings == NULL)
-		cached_directory_listings = g_hash_table_new 
-			(gnome_vfs_uri_hash, gnome_vfs_uri_hequal);
-}
-
-static void dircache_expire(GnomeVFSURI *uri) {
-	GList *list;
-	G_LOCK (cached_directory_listings);
-	dircache_setup();
-	list = g_hash_table_lookup(cached_directory_listings, uri);
-	G_UNLOCK (cached_directory_listings);
-}
-#endif
-
-
 #if ENABLE_FTP_DEBUG
 
 #define ftp_debug(c,g) FTP_DEBUG((c),(g),__FILE__, __LINE__, __PRETTY_FUNCTION__)
@@ -279,10 +266,10 @@ get_response (FtpConnection *conn)
 #endif
 
 		/* response needs to be at least: "### x"  - I think*/
-		if (isdigit ((unsigned char) line[0]) &&
-		    isdigit ((unsigned char) line[1]) &&
-		    isdigit ((unsigned char) line[2]) &&
-		    isspace ((unsigned char) line[3])) {
+		if (g_ascii_isdigit (line[0]) &&
+		    g_ascii_isdigit (line[1]) &&
+		    g_ascii_isdigit (line[2]) &&
+		    g_ascii_isspace (line[3])) {
 
 			conn->response_code = (line[0] - '0') * 100 + (line[1] - '0') * 10 + (line[2] - '0');
 
@@ -356,7 +343,7 @@ do_path_command (FtpConnection *conn,
 		 gchar *command,
 		 GnomeVFSURI *uri) 
 {
-	const char *path;
+	char *path;
 	char *actual_command;
 	GnomeVFSResult result;
 
@@ -366,11 +353,12 @@ do_path_command (FtpConnection *conn,
 	 */
 	path = gnome_vfs_unescape_string (uri->text, G_DIR_SEPARATOR_S);
 
-	if (path == NULL || strlen (path) == 0) {
-		path = ".";
+	if (path == NULL || path[0] == '\0') {
+		actual_command = g_strconcat (command, " .", NULL);
+	} else {
+		actual_command = g_strconcat (command, " ", path, NULL);
 	}
-
-	actual_command = g_strdup_printf ("%s %s", command, path);
+	g_free (path);
 
 	result = do_basic_command (conn, actual_command);
 	g_free (actual_command);
@@ -438,9 +426,7 @@ do_transfer_command (FtpConnection *conn, gchar *command, GnomeVFSContext *conte
 						   port,
 						   context ? gnome_vfs_context_get_cancellation(context) : NULL);
 
-	if (host != NULL) {
-	        g_free (host);
-	}
+	g_free (host);
 	if (result != GNOME_VFS_OK) {
 		return result;
 	}
@@ -474,20 +460,22 @@ do_transfer_command (FtpConnection *conn, gchar *command, GnomeVFSContext *conte
 static GnomeVFSResult
 do_path_transfer_command (FtpConnection *conn, gchar *command, GnomeVFSURI *uri, GnomeVFSContext *context) 
 {
-	const char *path;
+	char *path;
 	char *actual_command;
 	GnomeVFSResult result;
+
 	/* as some point we may need to make this execute a CD and then
   	 * a command using the basename rather than the full path. I am yet
 	 * to come across such a system.
 	 */
 	path = gnome_vfs_unescape_string (uri->text, G_DIR_SEPARATOR_S);
 
-	if (path == NULL || strlen (path) == 0) {
-		path = "/";
+	if (path == NULL || path[0] == '\0') {
+		actual_command = g_strconcat (command, " /", NULL);
+	} else {
+		actual_command = g_strconcat (command, " ", path, NULL);
 	}
-
-	actual_command = g_strdup_printf ("%s %s", command, path);
+	g_free (path);
 
 	result = do_transfer_command (conn, actual_command, context);
 	g_free (actual_command);
@@ -522,7 +510,7 @@ end_transfer (FtpConnection *conn)
 static GnomeVFSResult 
 ftp_connection_create (FtpConnection **connptr, GnomeVFSURI *uri, GnomeVFSContext *context) 
 {
-	FtpConnection *conn = g_new (FtpConnection, 1);
+	FtpConnection *conn = g_new0 (FtpConnection, 1);
 	GnomeVFSResult result;
 	gchar *tmpstring;
 	gint port = control_port;
@@ -530,11 +518,7 @@ ftp_connection_create (FtpConnection **connptr, GnomeVFSURI *uri, GnomeVFSContex
 	const gchar *pass = anon_pass;
 	
 	conn->uri = gnome_vfs_uri_dup (uri);
-	conn->cwd = NULL;
-	conn->data_connection = NULL;
-	conn->data_iobuf = NULL;
 	conn->response_buffer = g_string_new ("");
-	conn->response_message = NULL;
 	conn->response_code = -1;
 	conn->anonymous = TRUE;
 	conn->fivefifty = GNOME_VFS_ERROR_NOT_FOUND;
@@ -562,6 +546,7 @@ ftp_connection_create (FtpConnection **connptr, GnomeVFSURI *uri, GnomeVFSContex
 			   gnome_vfs_uri_get_host_name (uri),
 			   gnome_vfs_uri_get_host_port (uri),
 			   gnome_vfs_result_to_string (result));
+		gnome_vfs_uri_unref (conn->uri);
 		g_string_free (conn->response_buffer, TRUE);
 		g_free (conn);
 		return result;
@@ -572,6 +557,7 @@ ftp_connection_create (FtpConnection **connptr, GnomeVFSURI *uri, GnomeVFSContex
 	if (conn->iobuf == NULL) {
 		g_warning ("gnome_vfs_inet_connection_get_iobuf () failed");
 		gnome_vfs_inet_connection_destroy (conn->inet_connection, NULL);
+		gnome_vfs_uri_unref (conn->uri);
 		g_string_free (conn->response_buffer, TRUE);
 		g_free (conn);
 		return GNOME_VFS_ERROR_GENERIC;
@@ -584,6 +570,7 @@ ftp_connection_create (FtpConnection **connptr, GnomeVFSURI *uri, GnomeVFSContex
 			   gnome_vfs_uri_get_host_name (uri),
 			   gnome_vfs_uri_get_host_port (uri), 
 			   conn->response_code, conn->response_message);
+		gnome_vfs_uri_unref (conn->uri);
 		g_string_free (conn->response_buffer, TRUE);
 		g_free (conn);
 		return result;
@@ -605,6 +592,8 @@ ftp_connection_create (FtpConnection **connptr, GnomeVFSURI *uri, GnomeVFSContex
 			   conn->response_message);
 		gnome_vfs_iobuf_destroy (conn->iobuf);
 		gnome_vfs_inet_connection_destroy (conn->inet_connection, NULL);
+		gnome_vfs_uri_unref (conn->uri);
+		g_string_free (conn->response_buffer, TRUE);
 		g_free (conn);
 		return result;
 	}
@@ -659,25 +648,25 @@ ftp_connection_destroy (FtpConnection *conn)
 	total_connections--;
 }
 
-/* g_str_hash and g_str_equal seem to fail with null arguments */
+/* g_str_hash and g_str_equal don't take null arguments */
 
-static gint 
-my_str_hash (const gchar *c) 
+static guint 
+my_str_hash (const char *c) 
 {
 	if (c) 
 	        return g_str_hash (c);
-	else return 0;
+	return 0;
 }
 
-static gint 
-my_str_equal (gconstpointer c, 
-	      gconstpointer d) 
+static gboolean
+my_str_equal (const char *c, 
+	      const char *d) 
 {
 	if ((c && !d) || (d &&!c)) 
 		return FALSE;
 	if (!c && !d) 
 		return TRUE;
-	return g_str_equal (c,d);
+	return strcmp (c,d) == 0;
 }
 
 /* hash the bits of a GnomeVFSURI that distingush FTP connections */
@@ -734,12 +723,6 @@ ftp_connection_acquire (GnomeVFSURI *uri, FtpConnection **connection, GnomeVFSCo
 		ftp_debug (conn, strdup ("found a connection"));
 #endif
 		possible_connections = g_list_remove (possible_connections, conn);
-
-		if(!g_hash_table_lookup (spare_connections, uri)) {
-			/* uri will be used as a key in the hashtable */
-			uri = gnome_vfs_uri_dup (uri);
-		}
-
 		g_hash_table_insert (spare_connections, uri, possible_connections);
 
 		/* make sure connection hasn't timed out */
@@ -757,7 +740,9 @@ ftp_connection_acquire (GnomeVFSURI *uri, FtpConnection **connection, GnomeVFSCo
 
 	*connection = conn;
 
-	if(result == GNOME_VFS_OK) allocated_connections++;
+	if (result == GNOME_VFS_OK) {
+		allocated_connections++;
+	}
 
 	return result;
 }
@@ -936,12 +921,12 @@ ls_to_file_info (gchar *ls, GnomeVFSFileInfo *file_info,
 		   would give the stat_to_file_info function this
 		   information.  Also, there may be more fields here that are not 
 		   valid that we haven't dealt with.  */
-		file_info->valid_fields -= GNOME_VFS_FILE_INFO_FIELDS_DEVICE;
-		file_info->valid_fields -= GNOME_VFS_FILE_INFO_FIELDS_INODE;
-		file_info->valid_fields -= GNOME_VFS_FILE_INFO_FIELDS_IO_BLOCK_SIZE;
+		file_info->valid_fields |= ~(GNOME_VFS_FILE_INFO_FIELDS_DEVICE
+					     | GNOME_VFS_FILE_INFO_FIELDS_INODE
+					     | GNOME_VFS_FILE_INFO_FIELDS_IO_BLOCK_SIZE);
 		file_info->io_block_size = 0;
 
-		file_info->name = g_strdup (g_basename(filename));
+		file_info->name = g_path_get_basename (filename);
 
 		if(*(file_info->name) == '\0') {
 			g_free (file_info->name);
@@ -1069,13 +1054,12 @@ do_get_file_info (GnomeVFSMethod *method,
 		file_info->mime_type = g_strdup ("x-directory/normal");
 		file_info->valid_fields = GNOME_VFS_FILE_INFO_FIELDS_TYPE |
 			GNOME_VFS_FILE_INFO_FIELDS_MIME_TYPE;
-		return GNOME_VFS_OK;
 	} else {
 		GnomeVFSMethodHandle *method_handle;
 		gchar *name;
 
 		result = do_open_directory (method, &method_handle, parent,
-					    options, NULL, context);
+					    options, context);
 
 		gnome_vfs_uri_unref (parent);
 
@@ -1085,26 +1069,23 @@ do_get_file_info (GnomeVFSMethod *method,
 
 	       	name = gnome_vfs_uri_extract_short_name (uri);
 
-		while (result == GNOME_VFS_OK) {
+		while (1) {
 			result = do_read_directory (method, method_handle, 
 						    file_info, context);
-			if (result == GNOME_VFS_OK) {
-				if (file_info->name && !strcmp (file_info->name,
-								name)) {
-					g_free (name);
-					do_close_directory(
-							method, method_handle,
-						       	context);
-					return GNOME_VFS_OK;
-				}
-
-				gnome_vfs_file_info_clear (file_info);
+			if (result != GNOME_VFS_OK) {
+				result = GNOME_VFS_ERROR_NOT_FOUND;
+				break;
+			}
+			if (file_info->name != NULL
+			    && strcmp (file_info->name, name) == 0) {
+				break;
 			}
 		}
-		do_close_directory(method, method_handle, context);
+		g_free (name);
+		do_close_directory (method, method_handle, context);
 	}
 
-	return GNOME_VFS_ERROR_NOT_FOUND;
+	return result;
 }
 
 static GnomeVFSResult
@@ -1124,11 +1105,8 @@ do_open_directory (GnomeVFSMethod *method,
 		   GnomeVFSMethodHandle **method_handle,
 		   GnomeVFSURI *uri,
 		   GnomeVFSFileInfoOptions options,
-		   const GnomeVFSDirectoryFilter *filter,
 		   GnomeVFSContext *context)
 {
-	/* FIXME bugzilla.eazel.com 1137: implement filters */
-
 	FtpConnection *conn;
 	GnomeVFSResult result;
 	GnomeVFSFileSize num_bytes = 1024, bytes_read;
@@ -1257,8 +1235,7 @@ do_read_directory (GnomeVFSMethod *method,
 			conn->dirlistptr++;
 		}
 		/* go past \r\n */
-		while (conn->dirlistptr && *conn->dirlistptr &&
-		       isspace ((unsigned char) (*conn->dirlistptr))) {
+		while (conn->dirlistptr && g_ascii_isspace (*conn->dirlistptr)) {
 			conn->dirlistptr++;
 		}
 
@@ -1428,21 +1405,6 @@ GnomeVFSMethod *
 vfs_module_init (const char *method_name, 
 		 const char *args)
 {
-#ifdef HAVE_GCONF
-	char *argv[] = {"vfs-ftp-method"};
-	int argc = 1;
-
-	/* Ensure GConf is initialized.  If more modules start to rely on
-	 * GConf, then this should probably be moved into a more 
-	 * central location
-	 */
-
-	if (!gconf_is_initialized ()) {
-		/* auto-initializes OAF if necessary */
-		gconf_init (argc, argv, NULL);
-	}
-#endif
-	
 	return &method;
 }
 
