@@ -20,27 +20,24 @@
 
    Author: Elliot Lee <sopwith@redhat.com> */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
-#include <glib.h>
-#include <string.h>
-#include <ctype.h>
-#ifdef HAVE_ALLOCA_H
-#include <alloca.h>
-#endif
-#include <unistd.h>
-#include <stdio.h>
+
 #include <errno.h>
+#include <fcntl.h>
+#include <glib/galloca.h>
+#include <glib/gmessages.h>
+#include <glib/gstrfuncs.h>
+#include <glib/gthread.h>
+#include <libgnomevfs/gnome-vfs-method.h>
+#include <libgnomevfs/gnome-vfs-mime.h>
+#include <libgnomevfs/gnome-vfs-module.h>
+#include <libgnomevfs/gnome-vfs-private-utils.h>
+#include <signal.h>
+#include <stdio.h>
+#include <string.h>
 #include <sys/types.h>
 #include <sys/wait.h>
-#include <fcntl.h>
-#include <signal.h>
-
-#include "gnome-vfs-method.h"
-#include "gnome-vfs-mime.h"
-#include "gnome-vfs-module.h"
-#include "gnome-vfs-private-utils.h"
+#include <unistd.h>
 
 typedef struct {
 	enum {
@@ -619,7 +616,6 @@ tr_do_open_directory(GnomeVFSMethod * method,
 		     GnomeVFSMethodHandle ** method_handle,
 		     GnomeVFSURI * uri,
 		     GnomeVFSFileInfoOptions options,
-		     const GnomeVFSDirectoryFilter * filter,
 		     GnomeVFSContext * context)
 {
 	TranslateMethod *tm = (TranslateMethod *) method;
@@ -632,7 +628,7 @@ tr_do_open_directory(GnomeVFSMethod * method,
 		retval =
 		    tm->real_method->open_directory(tm->real_method, method_handle,
 						    real_uri, options,
-						    filter, context);
+						    context);
 		gnome_vfs_uri_unref(real_uri);
 	} else {
 		retval = GNOME_VFS_ERROR_NOT_FOUND;
@@ -996,7 +992,7 @@ static int my_poptParseArgvString(char *buf, int *argcPtr, char ***argvPtr)
 	int argc = 0;
 	char *s;
 
-	s = alloca(strlen(buf) + 1);
+	s = g_alloca(strlen(buf) + 1);
 	strcpy(s, buf);
 
 	argv[argc] = buf;
@@ -1015,7 +1011,7 @@ static int my_poptParseArgvString(char *buf, int *argcPtr, char ***argvPtr)
 					*(buf++) = '\\';
 			}
 			*(buf++) = *src;
-		} else if (isspace((unsigned char)*src)) {
+		} else if (g_ascii_isspace(*src)) {
 			*buf = '\0';
 			if (*argv[argc]) {
 				buf++, argc++;
@@ -1074,7 +1070,7 @@ static gboolean tr_args_parse(ParsedArgs * pa, const char *args)
 
 	memset(pa, 0, sizeof(ParsedArgs));
 
-	tmp_args = alloca(strlen(args) + 1);
+	tmp_args = g_alloca(strlen(args) + 1);
 	strcpy(tmp_args, args);
 
 	if (my_poptParseArgvString(tmp_args, &argc, &argv)) {
@@ -1085,21 +1081,21 @@ static gboolean tr_args_parse(ParsedArgs * pa, const char *args)
 	for (i = 0; i < argc; i++) {
 #define CHECK_ARG() if((++i) >= argc) { badargs = TRUE; goto out; }
 #define CHECK_MODE(my_mode) if (mode_determined && pa->mode != (my_mode)) { badargs = TRUE ; goto out; } else { pa->mode = my_mode; mode_determined = TRUE; }
-		if (g_strcasecmp(argv[i], "-pattern") == 0) {
+		if (g_ascii_strcasecmp(argv[i], "-pattern") == 0) {
 			CHECK_ARG();
 			CHECK_MODE(MODE_BASIC);
 			pa->u.basic.trans_string = g_strdup(argv[i]);
-		} else if (g_strcasecmp(argv[i], "-real-method") == 0) {
+		} else if (g_ascii_strcasecmp(argv[i], "-real-method") == 0) {
 			CHECK_ARG();
 			pa->real_method_name = g_strdup(argv[i]);
-		} else if (g_strcasecmp(argv[i], "-exec") == 0) {
+		} else if (g_ascii_strcasecmp(argv[i], "-exec") == 0) {
 			CHECK_ARG();
 			CHECK_MODE(MODE_EXEC);
 			pa->u.exec.orig_string = g_strdup(argv[i]);
-		} else if (g_strcasecmp(argv[i], "-retain") == 0) {
+		} else if (g_ascii_strcasecmp(argv[i], "-retain") == 0) {
 			CHECK_MODE(MODE_EXEC);
 			pa->u.exec.retain = TRUE;
-		} else if (g_strcasecmp(argv[i], "-default-mime-type") == 0) {
+		} else if (g_ascii_strcasecmp(argv[i], "-default-mime-type") == 0) {
 			CHECK_ARG();
 			pa->default_mime_type = g_strdup(argv[i]);
 		} else {
